<?php
/**
 * Atavist Admin Class.
 *
 * @author  UNIM
 * @package Atavist
 * @since   Atavist 1.0.9.1
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Atavist_admin' ) ) :

	/**
	 * Atavist_admin Class.
	 */
	class Atavist_admin {

		/**
		 * Constructor.
		 */
		public function __construct() {
			add_action( 'admin_menu', array( $this, 'admin_menu' ) );
			add_action( 'wp_loaded', array( __CLASS__, 'hide_notices' ) );
			add_action( 'load-themes.php', array( $this, 'admin_notice' ) );
		}

		/**
		 * Add admin menu.
		 */
		public function admin_menu() {
			$theme = wp_get_theme( get_template() );

			$page = add_theme_page( esc_html__( 'About', 'atavist' ) . ' ' . $theme->display( 'Name' ), esc_html__( 'About', 'atavist' ) . ' ' . $theme->display( 'Name' ), 'activate_plugins', 'atavist-welcome', array(
				$this,
				'welcome_screen',
			) );
			add_action( 'admin_print_styles-' . $page, array( $this, 'enqueue_styles' ) );
		}

		/**
		 * Enqueue styles.
		 */
		public function enqueue_styles() {
			global $atavist_version;

			wp_enqueue_style( 'atavist-welcome', HEZARETHEME_URL . 'admin/assets/css/welcome.css', array(), $atavist_version );
		}

		/**
		 * Add admin notice.
		 */
		public function admin_notice() {
			global $atavist_version, $pagenow;

			wp_enqueue_style( 'atavist-message', HEZARETHEME_URL . 'admin/assets/css/message.css', array(), $atavist_version );

			// Let's bail on theme activation.
			if ( 'themes.php' == $pagenow && isset( $_GET['activated'] ) ) {
				add_action( 'admin_notices', array( $this, 'welcome_notice' ) );
				update_option( 'atavist_admin_notice_welcome', 1 );

				// No option? Let run the notice wizard again..
			} elseif ( ! get_option( 'atavist_admin_notice_welcome' ) ) {
				add_action( 'admin_notices', array( $this, 'welcome_notice' ) );
			}
		}

		/**
		 * Hide a notice if the GET variable is set.
		 */
		public static function hide_notices() {
			if ( isset( $_GET['atavist-hide-notice'] ) && isset( $_GET['_atavist_notice_nonce'] ) ) {
				if ( ! wp_verify_nonce( sanitize_text_field(wp_unslash($_GET['_atavist_notice_nonce'])), 'atavist_hide_notices_nonce' ) ) {
					wp_die( esc_html__( 'Action failed. Please refresh the page and retry.', 'atavist' ) );
				}

				if ( ! current_user_can( 'manage_options' ) ) {
					wp_die( esc_html__( 'Cheatin&#8217; huh?', 'atavist' ) );
				}

				$hide_notice = sanitize_text_field( wp_unslash($_GET['atavist-hide-notice']) );
				update_option( 'atavist_admin_notice_' . $hide_notice, 1 );
			}
		}

		/**
		 * Show welcome notice.
		 */
		public function welcome_notice() {
			?>
			<div id="message" class="updated atavist-message">
				<a class="atavist-message-close notice-dismiss" href="<?php echo esc_url( wp_nonce_url( remove_query_arg( array( 'activated' ), add_query_arg( 'atavist-hide-notice', 'welcome' ) ), 'atavist_hide_notices_nonce', '_atavist_notice_nonce' ) ); ?>"><?php esc_html_e( 'Dismiss', 'atavist' ); ?></a>
				<p><?php printf( esc_html__( 'Hi! Thank you for installing Atavist! To fully take advantage of atavists futures make sure you visit the %1$swelcome page%2$s.', 'atavist' ), '<a href="' . esc_url( admin_url( 'themes.php?page=atavist-welcome' ) ) . '">', '</a>' ); ?></p>
				<p class="submit">
					<a class="button-secondary" href="<?php echo esc_url( admin_url( 'themes.php?page=atavist-welcome' ) ); ?>"><?php esc_html_e( 'Get started with Atavist', 'atavist' ); ?></a>
				</p>
			</div>
			<?php
		}

		/**
		 * Intro text/links shown to all about pages.
		 *
		 * @access private
		 */
		private function intro() {
			global $atavist_version;

			$theme = wp_get_theme( get_template() );

			// Drop minor version if 0
			$major_version = substr( $atavist_version, 0, 3 );
			?>
			<div class="atavist-theme-info">
				<h1>
					<?php esc_html_e( 'About', 'atavist' ); ?>
					<?php echo esc_html($theme->display( 'Name' )); ?>
					<?php printf( '%s', esc_attr($major_version) ); ?>
				</h1>

				<div class="welcome-description-wrap">
					<div class="about-text"><?php echo esc_html( $theme->display( 'Description' ) ); ?></div>

					<div class="atavist-screenshot">
						<img src="<?php echo esc_url( get_template_directory_uri() ) . '/screenshot.png'; ?>" />
					</div>
				</div>
			</div>

				<?php $links_locale = get_locale();
				//var_dump($links_locale);?>

			<p class="atavist-actions">
				<?php if($links_locale == 'fa_IR'){
					?><a href="<?php echo esc_url( 'http://unim.ir/themes/atavist/?utm_source=atavist-about&utm_medium=theme-info-link&utm_campaign=theme-info&utm_gen=utmdc' ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'Theme Info', 'atavist' ); ?></a><?php
				}else{
					?><a href="<?php echo esc_url( 'https://unim.ir/en/themes-en/atavist-wordpress-multipurpose-theme/?utm_source=atavist-about&utm_medium=theme-info-link&utm_campaign=theme-info&utm_gen=utmdc' ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'Theme Info', 'atavist' ); ?></a><?php
				}?>
				
				<?php if($links_locale == 'fa_IR'){?>
					<a href="<?php echo esc_url( 'https://demo.unim.ir/atavist/' ); ?>" class="button button-secondary docs" target="_blank"><?php esc_html_e( 'View Demo', 'atavist' ); ?></a>
				<?php
				}else{?>
					<a href="<?php echo esc_url( 'https://demo.unim.ir/atavist-en/' ); ?>" class="button button-secondary docs" target="_blank"><?php esc_html_e( 'View Demo', 'atavist' ); ?></a>
				<?php } ?>

				<?php /* <a href="<?php echo esc_url( 'https://unim.ir/themes/atavist/?utm_source=atavist-about&utm_medium=view-pro-link&utm_campaign=view-pro#free-vs-pro' ); ?>" class="button button-primary docs" target="_blank"><?php esc_html_e( 'View PRO version', 'atavist' ); ?></a>*/ ?>

				<?php /* <a href="<?php echo esc_url( 'https://wordpress.org/support/theme/atavist/reviews/?filter=5' ); ?>" class="button button-secondary docs" target="_blank"><?php esc_html_e( 'Rate this theme', 'atavist' ); ?></a> */ ?>
			</p>

			<h2 class="nav-tab-wrapper">
				<?php $active_tab = isset($_GET['tab']);
				if ($active_tab){$tab_class = ' nav-tab-active';}else{$tab_class ='';}?>

				<a class="nav-tab <?php 
					if ( !isset($_GET['tab'])  && $_GET['page'] == 'atavist-welcome' ) {
					echo 'nav-tab-active';
				} ?>" href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'atavist-welcome' ), 'themes.php' ) ) ); ?>">
					<?php echo esc_html($theme->display( 'Name' )); ?>
				</a>
				<a class="nav-tab<?php echo esc_html($tab_class);?>" href="<?php echo esc_url( admin_url( add_query_arg( array(
					'page' => 'atavist-welcome',
					'tab'  => 'supported_plugins',
				), 'themes.php' ) ) ); ?>">
					<?php esc_html_e( 'Supported Plugins', 'atavist' ); ?>
				</a>
				<?php /*
				<a class="nav-tab <?php if ( isset( $_GET['tab'] ) && $_GET['tab'] == 'free_vs_pro' ) {
					echo 'nav-tab-active';
				} ?>" href="<?php echo esc_url( admin_url( add_query_arg( array(
					'page' => 'atavist-welcome',
					'tab'  => 'free_vs_pro',
				), 'themes.php' ) ) ); ?>">
					<?php esc_html_e( 'Free Vs Pro', 'atavist' ); ?>
				</a>
				<?php /*
				<a class="nav-tab <?php if ( isset( $_GET['tab'] ) && $_GET['tab'] == 'changelog' ) {
					echo 'nav-tab-active';
				} ?>" href="<?php echo esc_url( admin_url( add_query_arg( array(
					'page' => 'atavist-welcome',
					'tab'  => 'changelog',
				), 'themes.php' ) ) ); ?>">
					<?php esc_html_e( 'Changelog', 'atavist' ); ?>
				</a> */ ?>
			</h2>
			<?php
		}

		/**
		 * Welcome screen page.
		 */
		public function welcome_screen() {
			$current_tab = empty( $_GET['tab'] ) ? 'about' : $_GET['tab'];

			// Look for a {$current_tab}_screen method.
			if ( is_callable( array( $this, $current_tab . '_screen' ) ) ) {
				return $this->{$current_tab . '_screen'}();
			}

			// Fallback to about screen.
			return $this->about_screen();
		}

		/**
		 * Output the about screen.
		 */
		public function about_screen() {
			$theme = wp_get_theme( get_template() );
			?>
			<div class="wrap about-wrap">

				<?php $this->intro(); ?>

				<div class="changelog point-releases">
					<div class="under-the-hood two-col">
						<div class="col">
							<h3><?php esc_html_e( 'Theme Customizer', 'atavist' ); ?></h3>
							<p><?php esc_html_e( 'All Theme Options are available via Customize screen.', 'atavist' ) ?></p>
							<p>
								<a href="<?php echo esc_url(admin_url( 'customize.php' )); ?>" class="button button-secondary"><?php esc_html_e( 'Customize', 'atavist' ); ?></a>
							</p>
						</div>

						
						<div class="col">
							<h3><?php esc_html_e( 'Documentation', 'atavist' ); ?></h3>
							<p><?php esc_html_e( 'Please view our documentation page to setup the theme.', 'atavist' ) ?></p>
							<p>
							<?php $links_locale = get_locale();
								if($links_locale == 'fa_IR'){
								?><a href="<?php echo esc_url( 'http://unim.ir/themes/atavist/?utm_source=atavist-about&utm_medium=theme-info-link&utm_campaign=theme-info&utm_gen=utmdc' ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'Documentation', 'atavist' ); ?></a><?php
							}else{
								?><a href="<?php echo esc_url( 'https://unim.ir/en/themes-en/atavist-wordpress-multipurpose-theme/?utm_source=atavist-about&utm_medium=theme-info-link&utm_campaign=theme-info&utm_gen=utmdc' ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'Documentation', 'atavist' ); ?></a><?php
							}?>
							</p>
						</div>

						<?php /*
						<div class="col">
							<h3><?php esc_html_e( 'Got theme support question?', 'atavist' ); ?></h3>
							<p><?php esc_html_e( 'Please put it in our dedicated support forum.', 'atavist' ) ?></p>
							<p>
								<a href="<?php echo esc_url( 'https://unim.ir/support-forum/?utm_source=atavist-about&utm_medium=support-forum-link&utm_campaign=support-forum' ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'Support Forum', 'atavist' ); ?></a>
							</p>
						</div>
						*/?>

						<?php /*
						<div class="col">
							<h3><?php esc_html_e( 'Need more features?', 'atavist' ); ?></h3>
							<p><?php esc_html_e( 'Upgrade to PRO version for more exciting features.', 'atavist' ) ?></p>
							<p>
								<a href="<?php echo esc_url( 'https://unim.ir/themes/atavist/?utm_source=atavist-about&utm_medium=view-pro-link&utm_campaign=view-pro#free-vs-pro' ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'View Pro', 'atavist' ); ?></a>
							</p>
						</div>

						<div class="col">
							<h3><?php esc_html_e( 'Got sales related question?', 'atavist' ); ?></h3>
							<p><?php esc_html_e( 'Please send it via our sales contact page.', 'atavist' ) ?></p>
							<p>
								<a href="<?php echo esc_url( 'https://unim.ir/contact-form/?utm_source=atavist-about&utm_medium=contact-page-link&utm_campaign=contact-page' ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'Contact Page', 'atavist' ); ?></a>
							</p>
						</div>

						<div class="col">
							<h3>
								<?php
								esc_html_e( 'Translate', 'atavist' );
								echo ' ' . $theme->display( 'Name' );
								?>
							</h3>
							<p><?php esc_html_e( 'Click below to translate this theme into your own language.', 'atavist' ) ?></p>
							<p>
								<a href="<?php echo esc_url( 'http://translate.wordpress.org/projects/wp-themes/atavist' ); ?>" class="button button-secondary">
									<?php
									esc_html_e( 'Translate', 'atavist' );
									echo ' ' . $theme->display( 'Name' );
									?>
								</a>
							</p>
						</div>
						*/?>

					</div>
				</div>

				<div class="return-to-dashboard atavist">
					<?php if ( current_user_can( 'update_core' ) && isset( $_GET['updated'] ) ) : ?>
						<a href="<?php echo esc_url( self_admin_url( 'update-core.php' ) ); ?>">
							<?php is_multisite() ? esc_html_e( 'Return to Updates', 'atavist' ) : esc_html_e( 'Return to Dashboard &rarr; Updates', 'atavist' ); ?>
						</a> |
					<?php endif; ?>
					<a href="<?php echo esc_url( self_admin_url() ); ?>"><?php is_blog_admin() ? esc_html_e( 'Go to Dashboard &rarr; Home', 'atavist' ) : esc_html_e( 'Go to Dashboard', 'atavist' ); ?></a>
				</div>
			</div>
			<?php
		}

		/**
		 * Output the changelog screen.
		 */
		public function changelog_screen() {
			global $wp_filesystem;

			?>
			<div class="wrap about-wrap">

				<?php $this->intro(); ?>

				<p class="about-description"><?php esc_html_e( 'View changelog below:', 'atavist' ); ?></p>

				<?php
				$changelog_file = apply_filters( 'atavist_changelog_file', get_template_directory() . '/readme.txt' );

				// Check if the changelog file exists and is readable.
				if ( $changelog_file && is_readable( $changelog_file ) ) {
					WP_Filesystem();
					$changelog      = $wp_filesystem->get_contents( $changelog_file );
					$changelog_list = $this->parse_changelog( $changelog );

					echo wp_kses_post( $changelog_list );
				}
				?>
			</div>
			<?php
		}

		/**
		 * Parse changelog from readme file.
		 *
		 * @param  string $content
		 *
		 * @return string
		 */
		private function parse_changelog( $content ) {
			$matches   = null;
			$regexp    = '~==\s*Changelog\s*==(.*)($)~Uis';
			$changelog = '';

			if ( preg_match( $regexp, $content, $matches ) ) {
				$changes = explode( '\r\n', trim( $matches[1] ) );

				$changelog .= '<pre class="changelog">';

				foreach ( $changes as $index => $line ) {
					$changelog .= wp_kses_post( preg_replace( '~(=\s*Version\s*(\d+(?:\.\d+)+)\s*=|$)~Uis', '<span class="title">${1}</span>', $line ) );
				}

				$changelog .= '</pre>';
			}

			return wp_kses_post( $changelog );
		}

		/**
		 * Output the supported plugins screen.
		 */
		public function supported_plugins_screen() {
			?>
			<div class="wrap about-wrap">

				<?php $this->intro(); ?>

				<p class="about-description"><?php esc_html_e( 'This theme recommends following plugins:', 'atavist' ); ?></p>
				<ol>
					<?php /*
					<li>
						<a href="<?php echo esc_url( 'https://wordpress.org/plugins/social-icons/' ); ?>" target="_blank"><?php esc_html_e( 'Social Icons', 'atavist' ); ?></a>
						<?php esc_html_e( ' by unim', 'atavist' ); ?>
					</li>
					<li>
						<a href="<?php echo esc_url( 'https://wordpress.org/plugins/easy-social-sharing/' ); ?>" target="_blank"><?php esc_html_e( 'Easy Social Sharing', 'atavist' ); ?></a>
						<?php esc_html_e( ' by unim', 'atavist' ); ?>
					</li>
					*/ ?>
					<li>
						<a href="<?php echo esc_url( 'https://wordpress.org/plugins/contact-form-7/' ); ?>" target="_blank"><?php esc_html_e( 'Contact Form 7', 'atavist' ); ?></a>
					</li>
					<?php /*
					<li>
						<a href="<?php echo esc_url( 'https://wordpress.org/plugins/wp-pagenavi/' ); ?>" target="_blank"><?php esc_html_e( 'WP-PageNavi', 'atavist' ); ?></a>
					</li>
					 ?>
					<li>
						<a href="<?php echo esc_url( 'https://wordpress.org/plugins/woocommerce/' ); ?>" target="_blank"><?php esc_html_e( 'WooCommerce', 'atavist' ); ?></a>
						<?php esc_html_e( 'Fully Compatible in Pro Version', 'atavist' ); ?>
					</li>
					<li>
						<a href="<?php echo esc_url( 'https://wordpress.org/plugins/polylang/' ); ?>" target="_blank"><?php esc_html_e( 'Polylang', 'atavist' ); ?></a>
						<?php esc_html_e( 'Fully Compatible in Pro Version', 'atavist' ); ?>
					</li>
					<?php /*
					<li>
						<a href="<?php echo esc_url( 'https://wpml.org/' ); ?>" target="_blank"><?php esc_html_e( 'WPML', 'atavist' ); ?></a>
						<?php esc_html_e( 'Fully Compatible in Pro Version', 'atavist' ); ?>
					</li>
					*/ ?>
				</ol>

			</div>
			<?php
		}

		
	}

endif;

return new Atavist_admin();
